@@ -263,7 +263,7 @@ class CryptoFunction(str, Enum):
     UNKNOWN = 'unknown'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class AlgorithmProperties:
     """
     This is our internal representation of the cryptoPropertiesType.algorithmProperties ENUM type within the CycloneDX
@@ -514,7 +514,7 @@ class AlgorithmProperties:
         return f'<AlgorithmProperties primitive={self.primitive}, execution_environment={self.execution_environment}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class CertificateProperties:
     """
     This is our internal representation of the `cryptoPropertiesType.certificateProperties` complex type within
@@ -746,7 +746,7 @@ class RelatedCryptoMaterialState(str, Enum):
     SUSPENDED = 'suspended'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class RelatedCryptoMaterialSecuredBy:
     """
     This is our internal representation of the `cryptoPropertiesType.relatedCryptoMaterialProperties.securedBy` complex
@@ -817,7 +817,7 @@ class RelatedCryptoMaterialSecuredBy:
         return f'<RelatedCryptoMaterialSecuredBy mechanism={self.mechanism}, algorithm_ref={self.algorithm_ref}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class RelatedCryptoMaterialProperties:
     """
     This is our internal representation of the `cryptoPropertiesType.relatedCryptoMaterialProperties` complex type
@@ -1086,7 +1086,7 @@ class ProtocolPropertiesType(str, Enum):
     UNKNOWN = 'unknown'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class ProtocolPropertiesCipherSuite:
     """
     This is our internal representation of the `cryptoPropertiesType.protocolProperties.cipherSuites.cipherSuite`
@@ -1179,7 +1179,7 @@ class ProtocolPropertiesCipherSuite:
         return f'<ProtocolPropertiesCipherSuite name={self.name}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class Ikev2TransformTypes:
     """
     This is our internal representation of the `cryptoPropertiesType.protocolProperties.ikev2TransformTypes`
@@ -1321,7 +1321,7 @@ class Ikev2TransformTypes:
         return f'<Ikev2TransformTypes esn={self.esn}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class ProtocolProperties:
     """
     This is our internal representation of the `cryptoPropertiesType.protocolProperties` complex type within
@@ -1447,7 +1447,7 @@ class ProtocolProperties:
         return f'<ProtocolProperties type={self.type}, version={self.version}>'
 
 
-@serializable.serializable_class
+@serializable.serializable_class(ignore_unknown_during_deserialization=True)
 class CryptoProperties:
     """
     This is our internal representation of the `cryptoPropertiesType` complex type within CycloneDX standard.
